aboutsummaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorraysan5 <raysan5@gmail.com>2017-01-05 19:33:05 +0100
committerraysan5 <raysan5@gmail.com>2017-01-05 19:33:05 +0100
commit658c2806690ace34a0dae6b6ed12d0ea52d2d6e4 (patch)
treee726d130c81f429e70d1c36b91aef5454658efb9 /examples
parent0369bb4c8cfe8988634a09d56c307b73be281452 (diff)
downloadraylib-658c2806690ace34a0dae6b6ed12d0ea52d2d6e4.tar.gz
raylib-658c2806690ace34a0dae6b6ed12d0ea52d2d6e4.zip
Lattest PR review
Function names, code formatting...
Diffstat (limited to 'examples')
-rw-r--r--examples/Makefile11
-rw-r--r--examples/models_ray_picking.c (renamed from examples/core_3d_raypick.c)130
2 files changed, 71 insertions, 70 deletions
diff --git a/examples/Makefile b/examples/Makefile
index 676529c7..80437590 100644
--- a/examples/Makefile
+++ b/examples/Makefile
@@ -203,7 +203,6 @@ EXAMPLES = \
core_gestures_detection \
core_3d_mode \
core_3d_picking \
- core_3d_raypick \
core_3d_camera_free \
core_3d_camera_first_person \
core_2d_camera \
@@ -237,6 +236,7 @@ EXAMPLES = \
models_obj_loading \
models_heightmap \
models_cubicmap \
+ models_ray_picking \
shaders_model_shader \
shaders_shapes_textures \
shaders_custom_uniform \
@@ -321,11 +321,6 @@ core_3d_mode: core_3d_mode.c
core_3d_picking: core_3d_picking.c
$(CC) -o $@$(EXT) $< $(CFLAGS) $(INCLUDES) $(LFLAGS) $(LIBS) -D$(PLATFORM) $(WINFLAGS)
-# compile [core] example - 3d ray picking
-core_3d_raypick: core_3d_raypick.c
- $(CC) -o $@$(EXT) $< $(CFLAGS) $(INCLUDES) $(LFLAGS) $(LIBS) -D$(PLATFORM) $(WINFLAGS)
-
-
# compile [core] example - 3d camera free
core_3d_camera_free: core_3d_camera_free.c
$(CC) -o $@$(EXT) $< $(CFLAGS) $(INCLUDES) $(LFLAGS) $(LIBS) -D$(PLATFORM) $(WINFLAGS)
@@ -462,6 +457,10 @@ models_heightmap: models_heightmap.c
models_cubicmap: models_cubicmap.c
$(CC) -o $@$(EXT) $< $(CFLAGS) $(INCLUDES) $(LFLAGS) $(LIBS) -D$(PLATFORM) $(WINFLAGS)
+# compile [models] example - model ray picking
+models_ray_picking: models_ray_picking.c
+ $(CC) -o $@$(EXT) $< $(CFLAGS) $(INCLUDES) $(LFLAGS) $(LIBS) -D$(PLATFORM) $(WINFLAGS)
+
# compile [shaders] example - model shader
shaders_model_shader: shaders_model_shader.c
$(CC) -o $@$(EXT) $< $(CFLAGS) $(INCLUDES) $(LFLAGS) $(LIBS) -D$(PLATFORM) $(WINFLAGS)
diff --git a/examples/core_3d_raypick.c b/examples/models_ray_picking.c
index cf56b277..c578a185 100644
--- a/examples/core_3d_raypick.c
+++ b/examples/models_ray_picking.c
@@ -1,8 +1,8 @@
/*******************************************************************************************
*
* raylib [core] example - Ray-Picking in 3d mode, ground plane, triangle, mesh
*
-* This example has been created using raylib 1.3 (www.raylib.com)
+* This example has been created using raylib 1.7 (www.raylib.com)
* raylib is licensed under an unmodified zlib/libpng license (View raylib.h for details)
*
* Copyright (c) 2015 Ramon Santamaria (@raysan5)
@@ -11,7 +11,7 @@
********************************************************************************************/
#include "raylib.h"
-#include "raymath.h"
+#include "../src/raymath.h"
#include <stdio.h>
#include <float.h>
@@ -24,7 +24,7 @@ int main()
int screenWidth = 800;
int screenHeight = 450;
- InitWindow(screenWidth, screenHeight, "raylib [core] example - 3d ray picking");
+ InitWindow(screenWidth, screenHeight, "raylib [models] example - 3d ray picking");
// Define the camera to look into our 3d world
Camera camera;
@@ -41,22 +41,22 @@ int main()
Model tower = LoadModel("resources/model/lowpoly-tower.obj"); // Load OBJ model
Texture2D texture = LoadTexture("resources/model/lowpoly-tower.png"); // Load model texture
tower.material.texDiffuse = texture; // Set model diffuse texture
+
Vector3 towerPos = { 0.0f, 0.0f, 0.0f }; // Set model position
BoundingBox towerBBox = CalculateBoundingBox( tower.mesh );
- bool hitMeshBBox;
- bool hitTriangle;
+ bool hitMeshBBox = false;
+ bool hitTriangle = false;
// Test triangle
Vector3 ta = (Vector3){ -25.0, 0.5, 0.0 };
Vector3 tb = (Vector3){ -4.0, 2.5, 1.0 };
Vector3 tc = (Vector3){ -8.0, 6.5, 0.0 };
- Vector3 bary = {0};
+ Vector3 bary = { 0.0f, 0.0f, 0.0f };
SetCameraMode(camera, CAMERA_FREE); // Set a free camera mode
SetTargetFPS(60); // Set our game to run at 60 frames-per-second
-
//--------------------------------------------------------------------------------------
// Main game loop
while (!WindowShouldClose()) // Detect window close button or ESC key
@@ -65,7 +65,6 @@ int main()
//----------------------------------------------------------------------------------
UpdateCamera(&camera); // Update camera
-
// Display information about closest hit
RayHitInfo nearestHit;
char *hitObjectName = "None";
@@ -76,41 +75,50 @@ int main()
// Get ray and test against ground, triangle, and mesh
ray = GetMouseRay(GetMousePosition(), camera);
- RayHitInfo groundHitInfo = RaycastGroundPlane( ray, 0.0 );
- if ((groundHitInfo.hit) && (groundHitInfo.distance < nearestHit.distance)) {
+ // Check ray collision aginst ground plane
+ RayHitInfo groundHitInfo = GetCollisionRayGround(ray, 0.0f);
+
+ if ((groundHitInfo.hit) && (groundHitInfo.distance < nearestHit.distance))
+ {
nearestHit = groundHitInfo;
cursorColor = GREEN;
hitObjectName = "Ground";
}
- RayHitInfo triHitInfo = RaycastTriangle( ray, ta, tb, tc );
- if ((triHitInfo.hit) && (triHitInfo.distance < nearestHit.distance)) {
+ // Check ray collision against test triangle
+ RayHitInfo triHitInfo = GetCollisionRayTriangle(ray, ta, tb, tc);
+
+ if ((triHitInfo.hit) && (triHitInfo.distance < nearestHit.distance))
+ {
nearestHit = triHitInfo;
cursorColor = PURPLE;
hitObjectName = "Triangle";
- bary = Barycentric( nearestHit.hitPosition, ta, tb, tc );
+ bary = Barycenter(nearestHit.hitPosition, ta, tb, tc);
hitTriangle = true;
- } else {
- hitTriangle = false;
- }
+ }
+ else hitTriangle = false;
RayHitInfo meshHitInfo;
- // check the bounding box first, before trying the full ray/mesh test
- if (CheckCollisionRayBox( ray, towerBBox )) {
+ // Check ray collision against bounding box first, before trying the full ray-mesh test
+ if (CheckCollisionRayBox(ray, towerBBox))
+ {
hitMeshBBox = true;
- meshHitInfo = RaycastMesh( ray, &tower.mesh );
- if ((meshHitInfo.hit) && (meshHitInfo.distance < nearestHit.distance)) {
+
+ // Check ray collision against mesh
+ meshHitInfo = GetCollisionRayMesh(ray, &tower.mesh);
+
+ if ((meshHitInfo.hit) && (meshHitInfo.distance < nearestHit.distance))
+ {
nearestHit = meshHitInfo;
cursorColor = ORANGE;
hitObjectName = "Mesh";
}
- } else {
- hitMeshBBox = false;
- }
-
+
+ } hitMeshBBox = false;
//----------------------------------------------------------------------------------
+
// Draw
//----------------------------------------------------------------------------------
BeginDrawing();
@@ -120,65 +128,59 @@ int main()
Begin3dMode(camera);
// Draw the tower
- DrawModel( tower, towerPos, 1.0, WHITE );
+ DrawModel(tower, towerPos, 1.0, WHITE);
// Draw the test triangle
- DrawLine3D( ta, tb, PURPLE );
- DrawLine3D( tb, tc, PURPLE );
- DrawLine3D( tc, ta, PURPLE );
+ DrawLine3D(ta, tb, PURPLE);
+ DrawLine3D(tb, tc, PURPLE);
+ DrawLine3D(tc, ta, PURPLE);
// Draw the mesh bbox if we hit it
- if (hitMeshBBox) {
- DrawBoundingBox( towerBBox, LIME );
- }
+ if (hitMeshBBox) DrawBoundingBox(towerBBox, LIME);
// If we hit something, draw the cursor at the hit point
- if (nearestHit.hit) {
- DrawCube( nearestHit.hitPosition, 0.5, 0.5, 0.5, cursorColor );
- DrawCubeWires( nearestHit.hitPosition, 0.5, 0.5, 0.5, YELLOW );
+ if (nearestHit.hit)
+ {
+ DrawCube(nearestHit.hitPosition, 0.5, 0.5, 0.5, cursorColor);
+ DrawCubeWires(nearestHit.hitPosition, 0.5, 0.5, 0.5, YELLOW);
Vector3 normalEnd;
normalEnd.x = nearestHit.hitPosition.x + nearestHit.hitNormal.x;
normalEnd.y = nearestHit.hitPosition.y + nearestHit.hitNormal.y;
normalEnd.z = nearestHit.hitPosition.z + nearestHit.hitNormal.z;
- DrawLine3D( nearestHit.hitPosition, normalEnd, YELLOW );
+
+ DrawLine3D(nearestHit.hitPosition, normalEnd, YELLOW);
}
DrawRay(ray, MAROON);
- DrawGrid(10, 1.0f);
+ DrawGrid(100, 1.0f);
End3dMode();
- // Show some debug text
- char line[1024];
- sprintf( line, "Hit Object: %s\n", hitObjectName );
- DrawText( line, 10, 30, 15, BLACK );
-
- if (nearestHit.hit) {
- int ypos = 45;
- sprintf( line, "Distance: %3.2f", nearestHit.distance );
- DrawText( line, 10, ypos, 15, BLACK );
- ypos += 15;
-
- sprintf( line, "Hit Pos: %3.2f %3.2f %3.2f",
- nearestHit.hitPosition.x, nearestHit.hitPosition.y, nearestHit.hitPosition.z );
- DrawText( line, 10, ypos, 15, BLACK );
- ypos += 15;
-
- sprintf( line, "Hit Norm: %3.2f %3.2f %3.2f",
- nearestHit.hitNormal.x, nearestHit.hitNormal.y, nearestHit.hitNormal.z );
- DrawText( line, 10, ypos, 15, BLACK );
- ypos += 15;
-
- if (hitTriangle) {
- sprintf( line, "Barycentric: %3.2f %3.2f %3.2f",
- bary.x, bary.y, bary.z );
- DrawText( line, 10, ypos, 15, BLACK );
- }
+ // Draw some debug GUI text
+ DrawText(FormatText("Hit Object: %s", hitObjectName), 10, 50, 10, BLACK);
+
+ if (nearestHit.hit)
+ {
+ int ypos = 70;
+
+ DrawText(FormatText("Distance: %3.2f", nearestHit.distance), 10, ypos, 10, BLACK);
+
+ DrawText(FormatText("Hit Pos: %3.2f %3.2f %3.2f",
+ nearestHit.hitPosition.x,
+ nearestHit.hitPosition.y,
+ nearestHit.hitPosition.z), 10, ypos + 15, 10, BLACK);
+
+ DrawText(FormatText("Hit Norm: %3.2f %3.2f %3.2f",
+ nearestHit.hitNormal.x,
+ nearestHit.hitNormal.y,
+ nearestHit.hitNormal.z), 10, ypos + 30, 10, BLACK);
+
+ if (hitTriangle) DrawText(FormatText("Barycenter: %3.2f %3.2f %3.2f", bary.x, bary.y, bary.z), 10, ypos + 45, 10, BLACK);
}
- DrawText( "Use Mouse to Move Camera", 10, 420, 15, LIGHTGRAY );
+ DrawText("Use Mouse to Move Camera", 10, 430, 10, GRAY);
DrawFPS(10, 10);
@@ -1,8 +1,8 @@
/*******************************************************************************************
*
-* raylib [core] example - Ray-Picking in 3d mode, ground plane, triangle, mesh
+* raylib [models] example - Ray picking in 3d mode, ground plane, triangle, mesh
*